@@ -20,7 +20,6 @@
 
 #include        "gvalue.h"
 #include        "genums.h"
-#include        "glibconfig.h" /* G_G[U]INT64_FORMAT */
 
 
 /* same type transforms
@@ -52,7 +51,7 @@ value_transform_##func_name (const GValue *src_value,                       \
 {                                                                           \
   ctype c_value = src_value->data[0].from_member;                           \
   dest_value->data[0].to_member = c_value;                                  \
-}
+} extern void glib_dummy_decl (void)
 DEFINE_CAST (int_s8,            v_int,    gint8,   v_int);
 DEFINE_CAST (int_u8,            v_int,    guint8,  v_uint);
 DEFINE_CAST (int_uint,          v_int,    guint,   v_uint);
@@ -143,7 +142,7 @@ value_transform_##func_name (const GValue *src_value,                       \
                              GValue       *dest_value)                      \
 {                                                                           \
   dest_value->data[0].v_int = src_value->data[0].from_member != 0;  \
-}
+} extern void glib_dummy_decl (void)
 DEFINE_BOOL_CHECK (int_bool,    v_int);
 DEFINE_BOOL_CHECK (uint_bool,   v_uint);
 DEFINE_BOOL_CHECK (long_bool,   v_long);
@@ -161,17 +160,13 @@ value_transform_##func_name (const GValue *src_value,                       \
 {                                                                           \
   dest_value->data[0].v_pointer = g_strdup_printf ((format),                \
 						   src_value->data[0].from_member);             \
-}
+} extern void glib_dummy_decl (void)
 DEFINE_SPRINTF (int_string,     v_int,    "%d");
 DEFINE_SPRINTF (uint_string,    v_uint,   "%u");
 DEFINE_SPRINTF (long_string,    v_long,   "%ld");
 DEFINE_SPRINTF (ulong_string,   v_ulong,  "%lu");
-#ifdef G_GINT64_FORMAT
 DEFINE_SPRINTF (int64_string,   v_int64,  "%" G_GINT64_FORMAT);
-#endif
-#ifdef G_GUINT64_FORMAT
 DEFINE_SPRINTF (uint64_string,  v_uint64, "%" G_GUINT64_FORMAT);
-#endif
 DEFINE_SPRINTF (float_string,   v_float,  "%f");
 DEFINE_SPRINTF (double_string,  v_double, "%f");
 
@@ -252,7 +247,8 @@ g_value_transforms_init (void)          /* sync with gtype.c */
   /* some transformations are a bit questionable,
    * we currently skip those
    */
-#define SKIP____register_transform_func(type1,type2,transform_func)     /* skip questionable transforms */
+#define SKIP____register_transform_func(type1,type2,transform_func)     /* skip questionable transforms */ \
+  (void)0
   
   /* numeric types (plus to string) */
   g_value_register_transform_func (G_TYPE_CHAR,         G_TYPE_CHAR,            value_transform_int_int);
@@ -366,9 +362,7 @@ g_value_transforms_init (void)          /* sync with gtype.c */
   g_value_register_transform_func (G_TYPE_INT64,        G_TYPE_FLAGS,           value_transform_int64_uint);
   g_value_register_transform_func (G_TYPE_INT64,        G_TYPE_FLOAT,           value_transform_int64_float);
   g_value_register_transform_func (G_TYPE_INT64,        G_TYPE_DOUBLE,          value_transform_int64_double);
-#ifdef G_GINT64_FORMAT
   g_value_register_transform_func (G_TYPE_INT64,        G_TYPE_STRING,          value_transform_int64_string);
-#endif
   g_value_register_transform_func (G_TYPE_UINT64,       G_TYPE_CHAR,            value_transform_uint64_s8);
   g_value_register_transform_func (G_TYPE_UINT64,       G_TYPE_UCHAR,           value_transform_uint64_u8);
   g_value_register_transform_func (G_TYPE_UINT64,       G_TYPE_BOOLEAN,         value_transform_uint64_bool);
@@ -385,9 +379,7 @@ g_value_transforms_init (void)          /* sync with gtype.c */
   g_value_register_transform_func (G_TYPE_UINT64,       G_TYPE_FLOAT,           value_transform_uint64_float);
   g_value_register_transform_func (G_TYPE_UINT64,       G_TYPE_DOUBLE,          value_transform_uint64_double);
 #endif
-#ifdef G_GUINT64_FORMAT
   g_value_register_transform_func (G_TYPE_UINT64,       G_TYPE_STRING,          value_transform_uint64_string);
-#endif
   g_value_register_transform_func (G_TYPE_ENUM,         G_TYPE_CHAR,            value_transform_int_s8);
   g_value_register_transform_func (G_TYPE_ENUM,         G_TYPE_UCHAR,           value_transform_int_u8);
   SKIP____register_transform_func (G_TYPE_ENUM,         G_TYPE_BOOLEAN,         value_transform_int_bool);
